@@ -5,7 +5,7 @@ use warnings;
 use base 'DBIx::Class::Schema::Loader::DBI::Component::QuotedDefault';
 use mro 'c3';
 
-our $VERSION = '0.07035';
+our $VERSION = '0.07036';
 
 =head1 NAME
 
@@ -43,7 +43,7 @@ sub _system_schemas {
 my %pg_rules = (
     a => 'NO ACTION',
     r => 'RESTRICT',
-    c => 'CASCADE,',
+    c => 'CASCADE',
     n => 'SET NULL',
     d => 'SET DEFAULT',
 );
@@ -95,7 +95,7 @@ EOF
         };
     }
 
-    return [ values %rels ];
+    return [ map { $rels{$_} } sort keys %rels ];
 }
 
 
@@ -293,12 +293,14 @@ EOF
             if ($typetype && $typetype eq 'e') {
                 # The following will extract a list of allowed values for the
                 # enum.
+                my $order_column = $self->dbh->{pg_server_version} >= 90100 ? 'enumsortorder' : 'oid';
                 my $typevalues = $self->dbh
                     ->selectall_arrayref(<<EOF, {}, $info->{data_type});
 SELECT e.enumlabel
 FROM pg_catalog.pg_enum e
 JOIN pg_catalog.pg_type t ON t.oid = e.enumtypid
 WHERE t.typname = ?
+ORDER BY e.$order_column
 EOF
 
                 $info->{extra}{list} = [ map { $_->[0] } @$typevalues ];
